package com.ruoyi.system.mapper.projectV2;

import java.util.List;
import com.ruoyi.system.domain.projectV2.ZsyzLdps;

/**
 * 招商引资_领导批示Mapper接口
 * 
 * @author ruoyi
 * @date 2023-02-26
 */
public interface ZsyzLdpsMapper 
{
    /**
     * 查询招商引资_领导批示
     * 
     * @param id 招商引资_领导批示主键
     * @return 招商引资_领导批示
     */
    public ZsyzLdps selectZsyzLdpsById(Long id);

    /**
     * 查询招商引资_领导批示列表
     * 
     * @param zsyzLdps 招商引资_领导批示
     * @return 招商引资_领导批示集合
     */
    public List<ZsyzLdps> selectZsyzLdpsList(ZsyzLdps zsyzLdps);

    /**
     * 新增招商引资_领导批示
     * 
     * @param zsyzLdps 招商引资_领导批示
     * @return 结果
     */
    public int insertZsyzLdps(ZsyzLdps zsyzLdps);

    /**
     * 修改招商引资_领导批示
     * 
     * @param zsyzLdps 招商引资_领导批示
     * @return 结果
     */
    public int updateZsyzLdps(ZsyzLdps zsyzLdps);

    /**
     * 删除招商引资_领导批示
     * 
     * @param id 招商引资_领导批示主键
     * @return 结果
     */
    public int deleteZsyzLdpsById(Long id);

    /**
     * 批量删除招商引资_领导批示
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteZsyzLdpsByIds(Long[] ids);

    ZsyzLdps getInfoZc(ZsyzLdps zsyzLdps);

    List<ZsyzLdps> selectZsyzLdpsNew(Long xmId);
}
